"use client"
import CheckItem from "./CheckItem"
import { CheckItemType } from "@/types/CheckItem"
import { useRef, useEffect, useState } from "react"
import {
  QueryClient,
  QueryClientProvider,
  useQueryClient,
} from "@tanstack/react-query"

const queryClient = new QueryClient()

export default function Checker() {
  // const IPv4 = useRef(null)
  const [IPv6, setIPv6] = useState(null)

  useEffect(() => {
    if (IPv6) {
      queryClient.invalidateQueries(
        {
          queryKey: ['ISP'],
          refetchType: 'all',
        },
      )
    }
  }, [IPv6])

  const checkList: CheckItemType[] = [
    {
      id: "IPv6",
      name: "公网 IPv6 地址",
      fetcher: () => fetch("/api/ip/myip").then((res) => res.json()),
      content: (data) => {
        const success = data?.version == 6
        if (success && data.address != null) {
          setIPv6(data.address)
        }
        return {
          state: success ? "ok" : "error",
          text: success ? `${data?.address}` : "未检测到",
        }
      },
    },
    {
      id: "IPv4",
      name: "公网 IPv4 地址",
      fetcher: () =>
        fetch("https://test.ipv6test.online/ip/myip").then((res) => res.json()),
      content: (data) => {
        const success = data?.version == 4

        // if (success && data.address != null) {
        //   IPv4.current = data.address
        // }

        return {
          state: success ? "ok" : "error",
          text: success ? `${data?.address}` : "未检测到",
        }
      },
    },
    {
      id: "ipv4andipv6",
      name: "双协议栈测试",
      fetcher: () => fetch("/api/ip/myip").then((res) => res.json()),
      content: (data) => {
        const isIPv6 = data?.version == 6
        const isIPv4 = data?.version == 4

        return {
          state: isIPv6 ? "ok" : "error",
          text: isIPv6 ? "IPv6访问优先" : isIPv4 ? "IPv4访问优先" : "未检测到",
        }
      },
    },
    {
      id: "ISP",
      name: "ISP",
      fetcher: () =>
        fetch("https://test.ipv6test.online/ip/isp", {
          method: "POST",
          body: JSON.stringify({
            address: IPv6,
          }),
        }).then((res) => res.json()),
      enabled: () => !!IPv6, // 确保在检测到 IPv6 地址时也进行 ISP 检查
      content: (data) => {
        return {
          state: data.isp ? "ok" : "error", // 确保返回 state 字段
          text: data.isp || "未检测到",
        }
      },
    },
  ]

  return (
    <QueryClientProvider client={queryClient}>
      {checkList.map((item, i) => {
        return (
          <CheckItem
            key={i}
            id={item.id}
            name={item.name}
            fetcher={item.fetcher}
            enabled={item.enabled}
            content={item.content}
          />
        )
      })}
    </QueryClientProvider>
  )
}
